[glib/wip/menus-rebase3] Minor doc improvements



commit 857ebe22a28cc336631dfd9d8de20c7ed85ee57c
Author: Matthias Clasen <mclasen redhat com>
Date:   Wed Nov 30 19:04:08 2011 -0500

    Minor doc improvements

 docs/reference/gio/gio-sections.txt |    1 -
 gio/gaction.c                       |    2 +-
 gio/gmenumodel.c                    |   18 +++++++++---------
 3 files changed, 10 insertions(+), 11 deletions(-)
---
diff --git a/docs/reference/gio/gio-sections.txt b/docs/reference/gio/gio-sections.txt
index b2768fd..15e6c33 100644
--- a/docs/reference/gio/gio-sections.txt
+++ b/docs/reference/gio/gio-sections.txt
@@ -3648,7 +3648,6 @@ G_IS_MENU_ITEM
 GMenuModel
 g_menu_model_is_mutable
 g_menu_model_get_n_items
-g_menu_model_get_item
 
 <SUBSECTION>
 G_MENU_ATTRIBUTE_ACTION
diff --git a/gio/gaction.c b/gio/gaction.c
index f2d9752..66e6dc9 100644
--- a/gio/gaction.c
+++ b/gio/gaction.c
@@ -28,7 +28,7 @@ G_DEFINE_INTERFACE (GAction, g_action, G_TYPE_OBJECT)
 /**
  * SECTION:gaction
  * @title: GAction
- * @short_description: An action
+ * @short_description: An action interface
  *
  * #GAction represents a single named action.
  *
diff --git a/gio/gmenumodel.c b/gio/gmenumodel.c
index 79e73be..e5737b3 100644
--- a/gio/gmenumodel.c
+++ b/gio/gmenumodel.c
@@ -633,7 +633,7 @@ g_menu_model_get_item_link (GMenuModel *model,
  * @removed: the number of items removed
  * @added: the number of items added
  *
- * Requests emission of the #GMenuMode::items-changed signal on @model.
+ * Requests emission of the #GMenuModel::items-changed signal on @model.
  *
  * This function should never be called except by #GMenuModel
  * subclasses.  Any other calls to this function will very likely lead
@@ -820,21 +820,21 @@ struct _GMenuLinkIterPrivate
 /**
  * g_menu_link_iter_get_next:
  * @iter: a #GMenuLinkIter
  * @out_name: (out) (allow-none) (transfer none): the name of the link
  * @value: (out) (allow-none) (transfer full): the linked #GMenuModel
  *
  * This function combines g_menu_link_iter_next() with
  * g_menu_link_iter_get_name() and g_menu_link_iter_get_value().
  *
- * First the iterator is advanced to the next (possibly first) link.  If
- * that fails, then %FALSE is returned and there are no other effects.
+ * First the iterator is advanced to the next (possibly first) link.
+ * If that fails, then %FALSE is returned and there are no other effects.
  *
  * If successful, @out_name and @value are set to the name and #GMenuModel
  * of the link that has just been advanced to.  At this point,
  * g_menu_item_get_name() and g_menu_item_get_value() will return the
  * same values again.
  *
  * The value returned in @out_name remains valid for as long as the iterator
  * remains at the current position.  The value returned in @value must
  * be unreffed using g_object_unref() when it is no longer in use.
  *
@@ -842,7 +842,7 @@ struct _GMenuLinkIterPrivate
  **/
 gboolean
 g_menu_link_iter_get_next (GMenuLinkIter  *iter,
-                           const gchar   **out_name,
+                           const gchar   **out_link,
                            GMenuModel    **value)
 {
   const gchar *name;
@@ -861,8 +861,8 @@ g_menu_link_iter_get_next (GMenuLinkIter  *iter,
       g_assert (name != NULL);
 
       iter->priv->name = g_quark_from_string (name);
-      if (out_name)
-        *out_name = g_quark_to_string (iter->priv->name);
+      if (out_link)
+        *out_link = g_quark_to_string (iter->priv->name);
 
       if (value)
         *value = g_object_ref (iter->priv->value);
@@ -820,21 +820,21 @@ struct _GMenuLinkIterPrivate
  * g_menu_link_iter_get_next:
  * @iter: a #GMenuLinkIter
- * @out_name: (out) (allow-none) (transfer none): the name of the link
+ * @out_link: (out) (allow-none) (transfer none): the name of the link
  * @value: (out) (allow-none) (transfer full): the linked #GMenuModel
  *
@@ -820,21 +820,21 @@ struct _GMenuLinkIterPrivate
  *
- * If successful, @out_name and @value are set to the name and #GMenuModel
+ * If successful, @out_link and @value are set to the name and #GMenuModel
  * of the link that has just been advanced to.  At this point,
  * g_menu_item_get_name() and g_menu_item_get_value() will return the
@@ -820,21 +820,21 @@ struct _GMenuLinkIterPrivate
  * same values again.
  *
- * The value returned in @out_name remains valid for as long as the iterator
+ * The value returned in @out_link remains valid for as long as the iterator
  * remains at the current position.  The value returned in @value must
  * be unreffed using g_object_unref() when it is no longer in use.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]